@@ -28,6 +28,15 @@ from rich.theme import Theme
 from ptscripts import logs
 from ptscripts import process
 
+try:
+    import importlib.metadata
+
+    __version__ = importlib.metadata.version("python-tools-scripts")
+except ImportError:
+    import importlib_metadata
+
+    __version__ = importlib_metadata.version("python-tools-scripts")
+
 if TYPE_CHECKING:
     from argparse import ArgumentParser
     from argparse import _SubParsersAction
@@ -136,6 +145,7 @@ class Context:
         self,
         *cmdline,
         check=True,
+        timeout_secs: int | None = None,
         no_output_timeout_secs: int | None = None,
         capture: bool = False,
         interactive: bool = False,
@@ -146,6 +156,7 @@ class Context:
         return process.run(
             *cmdline,
             check=check,
+            timeout_secs=timeout_secs,
             no_output_timeout_secs=no_output_timeout_secs,
             capture=capture,
             interactive=interactive,
@@ -192,6 +203,7 @@ class Parser:
                 epilog="These tools are discovered under `<repo-root>/tools`.",
                 allow_abbrev=False,
             )
+            instance.parser.add_argument("--version", action="version", version=__version__)
             log_group = instance.parser.add_argument_group("Logging")
             timestamp_meg = log_group.add_mutually_exclusive_group()
             timestamp_meg.add_argument(
@@ -228,6 +240,15 @@ class Parser:
             run_options = instance.parser.add_argument_group(
                 "Run Subprocess Options", description="These options apply to ctx.run() calls"
             )
+            run_options.add_argument(
+                "--timeout-secs",
+                "--ts",
+                default=None,
+                type=int,
+                help="Timeout in seconds for the command to finish.",
+                metavar="SECONDS",
+                dest="timeout_secs",
+            )
             run_options.add_argument(
                 "--no-output-timeout-secs",
                 "--nots",
